Class: NetworkApi::BgpIPv4Prefix

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_network_api/models/bgp_ipv4_prefix.rb

Overview

The BGP IPv4 Prefix. Deprecated in favour of generic BgpIpPrefix.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BgpIPv4Prefix

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/pnap_network_api/models/bgp_ipv4_prefix.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NetworkApi::BgpIPv4Prefix` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NetworkApi::BgpIPv4Prefix`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ipv4_allocation_id')
    self.ipv4_allocation_id = attributes[:'ipv4_allocation_id']
  else
    self.ipv4_allocation_id = nil
  end

  if attributes.key?(:'cidr')
    self.cidr = attributes[:'cidr']
  else
    self.cidr = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'is_bring_your_own_ip')
    self.is_bring_your_own_ip = attributes[:'is_bring_your_own_ip']
  else
    self.is_bring_your_own_ip = nil
  end

  if attributes.key?(:'in_use')
    self.in_use = attributes[:'in_use']
  else
    self.in_use = nil
  end
end

Instance Attribute Details

#cidrObject

The IP block in CIDR format.



23
24
25
# File 'lib/pnap_network_api/models/bgp_ipv4_prefix.rb', line 23

def cidr
  @cidr
end

#in_useObject

The Boolean value of the BGP IPv4 Prefix is in use.



32
33
34
# File 'lib/pnap_network_api/models/bgp_ipv4_prefix.rb', line 32

def in_use
  @in_use
end

#ipv4_allocation_idObject

IPv4 allocation ID.



20
21
22
# File 'lib/pnap_network_api/models/bgp_ipv4_prefix.rb', line 20

def ipv4_allocation_id
  @ipv4_allocation_id
end

#is_bring_your_own_ipObject

Identifies IP as a ‘bring your own` IP block.



29
30
31
# File 'lib/pnap_network_api/models/bgp_ipv4_prefix.rb', line 29

def is_bring_your_own_ip
  @is_bring_your_own_ip
end

#statusObject

The BGP IPv4 Prefix status. Can have one of the following values: ‘PENDING`, `BUSY`, `READY`, `ERROR` and `DELETING`.



26
27
28
# File 'lib/pnap_network_api/models/bgp_ipv4_prefix.rb', line 26

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/pnap_network_api/models/bgp_ipv4_prefix.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/pnap_network_api/models/bgp_ipv4_prefix.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
# File 'lib/pnap_network_api/models/bgp_ipv4_prefix.rb', line 35

def self.attribute_map
  {
    :'ipv4_allocation_id' => :'ipv4AllocationId',
    :'cidr' => :'cidr',
    :'status' => :'status',
    :'is_bring_your_own_ip' => :'isBringYourOwnIp',
    :'in_use' => :'inUse'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/pnap_network_api/models/bgp_ipv4_prefix.rb', line 247

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/pnap_network_api/models/bgp_ipv4_prefix.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
# File 'lib/pnap_network_api/models/bgp_ipv4_prefix.rb', line 56

def self.openapi_types
  {
    :'ipv4_allocation_id' => :'String',
    :'cidr' => :'String',
    :'status' => :'String',
    :'is_bring_your_own_ip' => :'Boolean',
    :'in_use' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



222
223
224
225
226
227
228
229
230
# File 'lib/pnap_network_api/models/bgp_ipv4_prefix.rb', line 222

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ipv4_allocation_id == o.ipv4_allocation_id &&
      cidr == o.cidr &&
      status == o.status &&
      is_bring_your_own_ip == o.is_bring_your_own_ip &&
      in_use == o.in_use
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


234
235
236
# File 'lib/pnap_network_api/models/bgp_ipv4_prefix.rb', line 234

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



240
241
242
# File 'lib/pnap_network_api/models/bgp_ipv4_prefix.rb', line 240

def hash
  [ipv4_allocation_id, cidr, status, is_bring_your_own_ip, in_use].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/pnap_network_api/models/bgp_ipv4_prefix.rb', line 121

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @ipv4_allocation_id.nil?
    invalid_properties.push('invalid value for "ipv4_allocation_id", ipv4_allocation_id cannot be nil.')
  end

  if @cidr.nil?
    invalid_properties.push('invalid value for "cidr", cidr cannot be nil.')
  end

  pattern = Regexp.new(/^((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\/(?:[1-9]|[1-2]\d|3[0-2])$/)
  if @cidr !~ pattern
    invalid_properties.push("invalid value for \"cidr\", must conform to the pattern #{pattern}.")
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @is_bring_your_own_ip.nil?
    invalid_properties.push('invalid value for "is_bring_your_own_ip", is_bring_your_own_ip cannot be nil.')
  end

  if @in_use.nil?
    invalid_properties.push('invalid value for "in_use", in_use cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/pnap_network_api/models/bgp_ipv4_prefix.rb', line 269

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
157
158
159
160
161
162
163
# File 'lib/pnap_network_api/models/bgp_ipv4_prefix.rb', line 154

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @ipv4_allocation_id.nil?
  return false if @cidr.nil?
  return false if @cidr !~ Regexp.new(/^((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\/(?:[1-9]|[1-2]\d|3[0-2])$/)
  return false if @status.nil?
  return false if @is_bring_your_own_ip.nil?
  return false if @in_use.nil?
  true
end