Class: NetworkApi::BgpPeerGroupPatch
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NetworkApi::BgpPeerGroupPatch
- Defined in:
- lib/pnap_network_api/models/bgp_peer_group_patch.rb
Overview
Update a BGP Peer Group.
Instance Attribute Summary collapse
-
#advertised_routes ⇒ Object
The Advertised routes for the BGP Peer Group.
-
#asn ⇒ Object
The BGP Peer Group ASN.
-
#password ⇒ Object
The BGP Peer Group password.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BgpPeerGroupPatch
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BgpPeerGroupPatch
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/pnap_network_api/models/bgp_peer_group_patch.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NetworkApi::BgpPeerGroupPatch` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NetworkApi::BgpPeerGroupPatch`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'asn') self.asn = attributes[:'asn'] end if attributes.key?(:'password') self.password = attributes[:'password'] end if attributes.key?(:'advertised_routes') self.advertised_routes = attributes[:'advertised_routes'] end end |
Instance Attribute Details
#advertised_routes ⇒ Object
The Advertised routes for the BGP Peer Group. Can have one of the following values: ‘DEFAULT` and `NONE`.
26 27 28 |
# File 'lib/pnap_network_api/models/bgp_peer_group_patch.rb', line 26 def advertised_routes @advertised_routes end |
#asn ⇒ Object
The BGP Peer Group ASN.
20 21 22 |
# File 'lib/pnap_network_api/models/bgp_peer_group_patch.rb', line 20 def asn @asn end |
#password ⇒ Object
The BGP Peer Group password.
23 24 25 |
# File 'lib/pnap_network_api/models/bgp_peer_group_patch.rb', line 23 def password @password end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/pnap_network_api/models/bgp_peer_group_patch.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/pnap_network_api/models/bgp_peer_group_patch.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 |
# File 'lib/pnap_network_api/models/bgp_peer_group_patch.rb', line 29 def self.attribute_map { :'asn' => :'asn', :'password' => :'password', :'advertised_routes' => :'advertisedRoutes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/pnap_network_api/models/bgp_peer_group_patch.rb', line 170 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 |
# File 'lib/pnap_network_api/models/bgp_peer_group_patch.rb', line 57 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 |
# File 'lib/pnap_network_api/models/bgp_peer_group_patch.rb', line 48 def self.openapi_types { :'asn' => :'Integer', :'password' => :'String', :'advertised_routes' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
147 148 149 150 151 152 153 |
# File 'lib/pnap_network_api/models/bgp_peer_group_patch.rb', line 147 def ==(o) return true if self.equal?(o) self.class == o.class && asn == o.asn && password == o.password && advertised_routes == o.advertised_routes end |
#eql?(o) ⇒ Boolean
157 158 159 |
# File 'lib/pnap_network_api/models/bgp_peer_group_patch.rb', line 157 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
163 164 165 |
# File 'lib/pnap_network_api/models/bgp_peer_group_patch.rb', line 163 def hash [asn, password, advertised_routes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/pnap_network_api/models/bgp_peer_group_patch.rb', line 93 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@password.nil? && @password.to_s.length > 32 invalid_properties.push('invalid value for "password", the character length must be smaller than or equal to 32.') end if !@password.nil? && @password.to_s.length < 8 invalid_properties.push('invalid value for "password", the character length must be greater than or equal to 8.') end pattern = Regexp.new(/^[a-zA-Z0-9!@#$%^&*()\-|\[\]{}=;:<>,.]+$/) if !@password.nil? && @password !~ pattern invalid_properties.push("invalid value for \"password\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/pnap_network_api/models/bgp_peer_group_patch.rb', line 192 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
114 115 116 117 118 119 120 |
# File 'lib/pnap_network_api/models/bgp_peer_group_patch.rb', line 114 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@password.nil? && @password.to_s.length > 32 return false if !@password.nil? && @password.to_s.length < 8 return false if !@password.nil? && @password !~ Regexp.new(/^[a-zA-Z0-9!@#$%^&*()\-|\[\]{}=;:<>,.]+$/) true end |