Class: NetworkApi::PrivateNetwork

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_network_api/models/private_network.rb

Overview

Private Network details.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PrivateNetwork

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/pnap_network_api/models/private_network.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NetworkApi::PrivateNetwork` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NetworkApi::PrivateNetwork`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'vlan_id')
    self.vlan_id = attributes[:'vlan_id']
  else
    self.vlan_id = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  else
    self.location = nil
  end

  if attributes.key?(:'location_default')
    self.location_default = attributes[:'location_default']
  else
    self.location_default = nil
  end

  if attributes.key?(:'cidr')
    self.cidr = attributes[:'cidr']
  end

  if attributes.key?(:'servers')
    if (value = attributes[:'servers']).is_a?(Array)
      self.servers = value
    end
  else
    self.servers = nil
  end

  if attributes.key?(:'memberships')
    if (value = attributes[:'memberships']).is_a?(Array)
      self.memberships = value
    end
  else
    self.memberships = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'created_on')
    self.created_on = attributes[:'created_on']
  else
    self.created_on = nil
  end
end

Instance Attribute Details

#cidrObject

IP range associated with this private network in CIDR notation.



41
42
43
# File 'lib/pnap_network_api/models/private_network.rb', line 41

def cidr
  @cidr
end

#created_onObject

Date and time when this private network was created.



52
53
54
# File 'lib/pnap_network_api/models/private_network.rb', line 52

def created_on
  @created_on
end

#descriptionObject

The description of this private network.



26
27
28
# File 'lib/pnap_network_api/models/private_network.rb', line 26

def description
  @description
end

#idObject

The private network identifier.



20
21
22
# File 'lib/pnap_network_api/models/private_network.rb', line 20

def id
  @id
end

#locationObject

The location of this private network.



35
36
37
# File 'lib/pnap_network_api/models/private_network.rb', line 35

def location
  @location
end

#location_defaultObject

Identifies network as the default private network for the specified location.



38
39
40
# File 'lib/pnap_network_api/models/private_network.rb', line 38

def location_default
  @location_default
end

#membershipsObject

A list of resources that are members of this private network.



46
47
48
# File 'lib/pnap_network_api/models/private_network.rb', line 46

def memberships
  @memberships
end

#nameObject

The friendly name of this private network.



23
24
25
# File 'lib/pnap_network_api/models/private_network.rb', line 23

def name
  @name
end

#serversObject

Returns the value of attribute servers.



43
44
45
# File 'lib/pnap_network_api/models/private_network.rb', line 43

def servers
  @servers
end

#statusObject

The status of the private network. Can have one of the following values: ‘BUSY`, `READY`, `DELETING` or `ERROR`.



49
50
51
# File 'lib/pnap_network_api/models/private_network.rb', line 49

def status
  @status
end

#typeObject

The type of the private network.



32
33
34
# File 'lib/pnap_network_api/models/private_network.rb', line 32

def type
  @type
end

#vlan_idObject

The VLAN of this private network.



29
30
31
# File 'lib/pnap_network_api/models/private_network.rb', line 29

def vlan_id
  @vlan_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



73
74
75
# File 'lib/pnap_network_api/models/private_network.rb', line 73

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/pnap_network_api/models/private_network.rb', line 78

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/pnap_network_api/models/private_network.rb', line 55

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'vlan_id' => :'vlanId',
    :'type' => :'type',
    :'location' => :'location',
    :'location_default' => :'locationDefault',
    :'cidr' => :'cidr',
    :'servers' => :'servers',
    :'memberships' => :'memberships',
    :'status' => :'status',
    :'created_on' => :'createdOn'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/pnap_network_api/models/private_network.rb', line 431

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



101
102
103
104
# File 'lib/pnap_network_api/models/private_network.rb', line 101

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/pnap_network_api/models/private_network.rb', line 83

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'vlan_id' => :'Integer',
    :'type' => :'String',
    :'location' => :'String',
    :'location_default' => :'Boolean',
    :'cidr' => :'String',
    :'servers' => :'Array<PrivateNetworkServer>',
    :'memberships' => :'Array<NetworkMembership>',
    :'status' => :'String',
    :'created_on' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/pnap_network_api/models/private_network.rb', line 399

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      vlan_id == o.vlan_id &&
      type == o.type &&
      location == o.location &&
      location_default == o.location_default &&
      cidr == o.cidr &&
      servers == o.servers &&
      memberships == o.memberships &&
      status == o.status &&
      created_on == o.created_on
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


418
419
420
# File 'lib/pnap_network_api/models/private_network.rb', line 418

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



424
425
426
# File 'lib/pnap_network_api/models/private_network.rb', line 424

def hash
  [id, name, description, vlan_id, type, location, location_default, cidr, servers, memberships, status, created_on].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/pnap_network_api/models/private_network.rb', line 197

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 100
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@description.nil? && @description.to_s.length > 250
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 250.')
  end

  if @vlan_id.nil?
    invalid_properties.push('invalid value for "vlan_id", vlan_id cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @location.nil?
    invalid_properties.push('invalid value for "location", location cannot be nil.')
  end

  if @location_default.nil?
    invalid_properties.push('invalid value for "location_default", location_default cannot be nil.')
  end

  if @servers.nil?
    invalid_properties.push('invalid value for "servers", servers cannot be nil.')
  end

  if @memberships.nil?
    invalid_properties.push('invalid value for "memberships", memberships cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @created_on.nil?
    invalid_properties.push('invalid value for "created_on", created_on cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/pnap_network_api/models/private_network.rb', line 453

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/pnap_network_api/models/private_network.rb', line 257

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 100
  return false if @name.to_s.length < 1
  return false if !@description.nil? && @description.to_s.length > 250
  return false if @vlan_id.nil?
  return false if @type.nil?
  return false if @location.nil?
  return false if @location_default.nil?
  return false if @servers.nil?
  return false if @memberships.nil?
  return false if @status.nil?
  return false if @created_on.nil?
  true
end