Class: NetworkApi::PublicNetwork

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_network_api/models/public_network.rb

Overview

Public Network details.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PublicNetwork

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/pnap_network_api/models/public_network.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NetworkApi::PublicNetwork` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NetworkApi::PublicNetwork`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'vlan_id')
    self.vlan_id = attributes[:'vlan_id']
  else
    self.vlan_id = nil
  end

  if attributes.key?(:'memberships')
    if (value = attributes[:'memberships']).is_a?(Array)
      self.memberships = value
    end
  else
    self.memberships = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  else
    self.location = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'created_on')
    self.created_on = attributes[:'created_on']
  else
    self.created_on = nil
  end

  if attributes.key?(:'ip_blocks')
    if (value = attributes[:'ip_blocks']).is_a?(Array)
      self.ip_blocks = value
    end
  else
    self.ip_blocks = nil
  end

  if attributes.key?(:'ra_enabled')
    self.ra_enabled = attributes[:'ra_enabled']
  end
end

Instance Attribute Details

#created_onObject

Date and time when this public network was created.



41
42
43
# File 'lib/pnap_network_api/models/public_network.rb', line 41

def created_on
  @created_on
end

#descriptionObject

The description of this public network.



35
36
37
# File 'lib/pnap_network_api/models/public_network.rb', line 35

def description
  @description
end

#idObject

The public network identifier.



20
21
22
# File 'lib/pnap_network_api/models/public_network.rb', line 20

def id
  @id
end

#ip_blocksObject

A list of IP Blocks that are associated with this public network.



44
45
46
# File 'lib/pnap_network_api/models/public_network.rb', line 44

def ip_blocks
  @ip_blocks
end

#locationObject

The location of this public network. Supported values are ‘PHX`, `ASH`, `SGP`, `NLD`, `CHI` and `SEA`.



32
33
34
# File 'lib/pnap_network_api/models/public_network.rb', line 32

def location
  @location
end

#membershipsObject

A list of resources that are members of this public network.



26
27
28
# File 'lib/pnap_network_api/models/public_network.rb', line 26

def memberships
  @memberships
end

#nameObject

The friendly name of this public network.



29
30
31
# File 'lib/pnap_network_api/models/public_network.rb', line 29

def name
  @name
end

#ra_enabledObject

Boolean indicating whether Router Advertisement is enabled. Only applicable for Network with IPv6 Blocks.



47
48
49
# File 'lib/pnap_network_api/models/public_network.rb', line 47

def ra_enabled
  @ra_enabled
end

#statusObject

The status of the public network. Can have one of the following values: ‘BUSY`, `READY`, `DELETING` or `ERROR`.



38
39
40
# File 'lib/pnap_network_api/models/public_network.rb', line 38

def status
  @status
end

#vlan_idObject

The VLAN of this public network.



23
24
25
# File 'lib/pnap_network_api/models/public_network.rb', line 23

def vlan_id
  @vlan_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/pnap_network_api/models/public_network.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/pnap_network_api/models/public_network.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/pnap_network_api/models/public_network.rb', line 50

def self.attribute_map
  {
    :'id' => :'id',
    :'vlan_id' => :'vlanId',
    :'memberships' => :'memberships',
    :'name' => :'name',
    :'location' => :'location',
    :'description' => :'description',
    :'status' => :'status',
    :'created_on' => :'createdOn',
    :'ip_blocks' => :'ipBlocks',
    :'ra_enabled' => :'raEnabled'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/pnap_network_api/models/public_network.rb', line 378

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/pnap_network_api/models/public_network.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/pnap_network_api/models/public_network.rb', line 76

def self.openapi_types
  {
    :'id' => :'String',
    :'vlan_id' => :'Integer',
    :'memberships' => :'Array<NetworkMembership>',
    :'name' => :'String',
    :'location' => :'String',
    :'description' => :'String',
    :'status' => :'String',
    :'created_on' => :'Time',
    :'ip_blocks' => :'Array<PublicNetworkIpBlock>',
    :'ra_enabled' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/pnap_network_api/models/public_network.rb', line 348

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      vlan_id == o.vlan_id &&
      memberships == o.memberships &&
      name == o.name &&
      location == o.location &&
      description == o.description &&
      status == o.status &&
      created_on == o.created_on &&
      ip_blocks == o.ip_blocks &&
      ra_enabled == o.ra_enabled
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


365
366
367
# File 'lib/pnap_network_api/models/public_network.rb', line 365

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



371
372
373
# File 'lib/pnap_network_api/models/public_network.rb', line 371

def hash
  [id, vlan_id, memberships, name, location, description, status, created_on, ip_blocks, ra_enabled].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/pnap_network_api/models/public_network.rb', line 176

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @vlan_id.nil?
    invalid_properties.push('invalid value for "vlan_id", vlan_id cannot be nil.')
  end

  if @memberships.nil?
    invalid_properties.push('invalid value for "memberships", memberships cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 100
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @location.nil?
    invalid_properties.push('invalid value for "location", location cannot be nil.')
  end

  if !@description.nil? && @description.to_s.length > 250
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 250.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @created_on.nil?
    invalid_properties.push('invalid value for "created_on", created_on cannot be nil.')
  end

  if @ip_blocks.nil?
    invalid_properties.push('invalid value for "ip_blocks", ip_blocks cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/pnap_network_api/models/public_network.rb', line 400

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/pnap_network_api/models/public_network.rb', line 228

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @vlan_id.nil?
  return false if @memberships.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 100
  return false if @name.to_s.length < 1
  return false if @location.nil?
  return false if !@description.nil? && @description.to_s.length > 250
  return false if @status.nil?
  return false if @created_on.nil?
  return false if @ip_blocks.nil?
  true
end