Class: NetworkApi::PrivateNetworkModify
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NetworkApi::PrivateNetworkModify
- Defined in:
- lib/pnap_network_api/models/private_network_modify.rb
Overview
Object including details to be modified in the Private Network.
Instance Attribute Summary collapse
-
#description ⇒ Object
A description of this private network.
-
#location_default ⇒ Object
Identifies network as the default private network for the specified location.
-
#name ⇒ Object
A friendly name given to the private network.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PrivateNetworkModify
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PrivateNetworkModify
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/pnap_network_api/models/private_network_modify.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NetworkApi::PrivateNetworkModify` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NetworkApi::PrivateNetworkModify`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'location_default') self.location_default = attributes[:'location_default'] else self.location_default = nil end end |
Instance Attribute Details
#description ⇒ Object
A description of this private network
23 24 25 |
# File 'lib/pnap_network_api/models/private_network_modify.rb', line 23 def description @description end |
#location_default ⇒ Object
Identifies network as the default private network for the specified location.
26 27 28 |
# File 'lib/pnap_network_api/models/private_network_modify.rb', line 26 def location_default @location_default end |
#name ⇒ Object
A friendly name given to the private network. This name should be unique.
20 21 22 |
# File 'lib/pnap_network_api/models/private_network_modify.rb', line 20 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/pnap_network_api/models/private_network_modify.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/pnap_network_api/models/private_network_modify.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 |
# File 'lib/pnap_network_api/models/private_network_modify.rb', line 29 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'location_default' => :'locationDefault' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/pnap_network_api/models/private_network_modify.rb', line 213 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 |
# File 'lib/pnap_network_api/models/private_network_modify.rb', line 57 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 |
# File 'lib/pnap_network_api/models/private_network_modify.rb', line 48 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'location_default' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
190 191 192 193 194 195 196 |
# File 'lib/pnap_network_api/models/private_network_modify.rb', line 190 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && location_default == o.location_default end |
#eql?(o) ⇒ Boolean
200 201 202 |
# File 'lib/pnap_network_api/models/private_network_modify.rb', line 200 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
206 207 208 |
# File 'lib/pnap_network_api/models/private_network_modify.rb', line 206 def hash [name, description, location_default].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/pnap_network_api/models/private_network_modify.rb', line 97 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 100 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^(?=.*[a-zA-Z])([a-zA-Z0-9(). -])+$/) if @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end if !@description.nil? && @description.to_s.length > 250 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 250.') end if @location_default.nil? invalid_properties.push('invalid value for "location_default", location_default cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/pnap_network_api/models/private_network_modify.rb', line 235 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
130 131 132 133 134 135 136 137 138 139 |
# File 'lib/pnap_network_api/models/private_network_modify.rb', line 130 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length > 100 return false if @name.to_s.length < 1 return false if @name !~ Regexp.new(/^(?=.*[a-zA-Z])([a-zA-Z0-9(). -])+$/) return false if !@description.nil? && @description.to_s.length > 250 return false if @location_default.nil? true end |